# Dessia common

The common parts of the dessia SDK

## Purpose
The dessia sdk consists in a framework to build python apps that can be uploaded and interpreted by dessia platform instances. This package give a base class to make your object inherit.


## Installation

```
pip(3) install dessia_common 
```
pip can be named pip3 by your distribution.
Python at a version > 3.8 is required.

## Usage

The main usage is to make your objects inherit from dessia_common.DessiaObject
This will give them the powers to be handled by dessia platforms

## Changelog & roadmap

See markdown files in the repo CHANGELOG.md and ROADMAP.md for details.

